pub fn command(cmd: impl Into<String>) -> CommandFilterExpand description
Passes when the message is the given bot command (case-insensitive).
pub fn command(cmd: impl Into<String>) -> CommandFilterPasses when the message is the given bot command (case-insensitive).