Module handler

Module handler 

Handler trait and function wrapper.

Structs

HandlerFn
Wraps an async function (or closure) as a Handler.
LoggingHandler
A handler that logs any error from the wrapped handler and swallows it.

Traits

Handler
Core trait for all update handlers.

Functions

handler_fn
Creates a BoxHandler from any async function or closure.

Type Aliases

BoxHandler
A boxed, type-erased handler.
HandlerFuture
Type alias for the boxed future returned by handlers.