pub struct LoggingHandler { /* private fields */ }Expand description
A handler that logs any error from the wrapped handler and swallows it.
Implementations
Sourceimpl LoggingHandler
impl LoggingHandler
Sourcepub fn wrap(inner: BoxHandler) -> BoxHandler
pub fn wrap(inner: BoxHandler) -> BoxHandler
Wraps a handler so its errors are logged with the update ID and then
discarded, leaving the outer result Ok.